@@ -24,10 +24,12 @@ import sys
 import json
 import re
 
-from threading import Thread
+from threading import Thread, Event
 
 from tests.avro.mock_schema_registry_client import MockSchemaRegistryClient
 from confluent_kafka import avro
+from confluent_kafka.avro.error import ClientError
+
 
 if sys.version_info[0] < 3:
     import BaseHTTPServer as HTTPSERVER
@@ -120,7 +122,7 @@ class MockServer(HTTPSERVER.HTTPServer, object):
         try:
             avro_schema = avro.loads(schema)
             return self._get_identity_schema(avro_schema)
-        except:
+        except ClientError:
             return None
 
     def register(self, req, groups):
@@ -174,11 +176,18 @@ class ServerThread(Thread):
         self.server = None
         self.port = port
         self.daemon = True
+        self.started = Event()
 
     def run(self):
         self.server = MockServer(('127.0.0.1', self.port), ReqHandler)
+        self.started.set()
         self.server.serve_forever()
 
+    def start(self):
+        """Start, and wait for server to be fully started, before returning."""
+        super(ServerThread, self).start()
+        self.started.wait()
+
     def shutdown(self):
         if self.server:
             self.server.shutdown()
